==> ruby-nqxml-0.6.1.tgz: lib/ruby/site_ruby/1.6/nqxml/entities.rb <==
#
# Copyright (c) 2001 by Jim Menard <jimm@io.com>
#
# Released under the same license as Ruby. See
# http://www.ruby-lang.org/en/LICENSE.txt.
#

require 'nqxml/utils'

module NQXML

    class Entity

	attr_reader :source

	def initialize(source=nil)
	    @source = source
	end

	def to_s
	    return @source ? @source : ''
	end

	def ==(anObj)
	    return anObj.instance_of?(self.class) &&
		@source == anObj.source
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    io << self.to_s if beforeChildren
	end
    end

    # An abstract superclass for entities with names.
    class NamedEntity < Entity

	attr_reader :name

	def initialize(name, source=nil)
	    super(source)
	    @name = name
	end

	def ==(anObj)
	    return super(anObj) &&
		@name == anObj.name
	end
    end

    # An abstract superclass for entities with names and attributes.
    class NamedAttributes < NamedEntity
	attr_reader :attrs

	def initialize(name, attrs, source=nil)
	    super(name, source)
	    @attrs = attrs
	end

	def ==(anObj)
	    return super(anObj) &&
		@attrs == anObj.attrs
	end

	# Returns a string containing the attribute key/value pairs as XML.
	# Values are encoded.
	def attributesToXML
	    return '' if @attrs.nil?
	    str = ''
	    @attrs.each { | key, val |
		str += " #{key}=\"#{NQXML.encode(val)}\""
	    }
	    return str
	end

	# Returns a string containing the attribute key/value pairs as
	# a simple, unencoded string.
	def attributesToString
	    return '' if @attrs.nil?
	    str = ''
	    @attrs.each { | key, val |
		str += " #{key}=\"#{val}\""
	    }
	    return str
	end

    end

    class Tag < NamedAttributes

	attr_reader :isTagEnd

	def initialize(name, attrs, isTagEnd=false, source=nil)
	    super(name, attrs, source)
	    @isTagEnd = isTagEnd
	end

	def ==(anObj)
	    return super(anObj) &&
		@isTagEnd == anObj.isTagEnd
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# io might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    if beforeChildren
		io << "<#{name}" << attributesToXML() << ">"
	    else
		io << "</#{name}>"
	    end
	end

	# Prints tag. If it's start of tag, prints unencoded attributes.
	def to_s
	    return isTagEnd ? "</#{name}>" :
		"<#{name}" << attributesToString() << ">"
	end
    end

    class Text < Entity

	attr_reader :text

	def initialize(text, source=nil)
	    super(source)
	    @text = text
	end

	# We ignore the source attribute because during parsing entity
	# reference substitution may cause us to lose the ability to know
	# what the original XML source was.
	def ==(anObj)
	    return anObj.instance_of?(self.class) &&
  		@text == anObj.text
	end

	# Returns text with all entities replaced.
	def to_s
	    return @text
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# io might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    if beforeChildren
		io << @source if @source
		io << NQXML.encode(@text) if !@source
	    end
	end
    end

    class Comment < Entity

	attr_reader :text

	def initialize(source, internalEntities = nil)
	    super(source)

	    @source =~ /<!--(.*)-->/
	    @text = $1.strip()
	end

	def ==(anObj)
	    return super(anObj) &&
		@text == anObj.text
	end
    end

    class ProcessingInstruction < NamedAttributes

	def initialize(name, attrs, source=nil)
	    super(name, attrs, source)
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    io << "<?#{name}" << attributesToXML() << "?>" if beforeChildren
	end
    end

    class EntityTag < NamedEntity

	attr_reader :text

	def initialize(name, text, source=nil)
	    super(name, source)
	    @text = text
	end

	def ==(anObj)
	    return super(anObj) &&
		@text == anObj.text
	end
    end

    class GeneralEntityTag < EntityTag
    end

    class ParameterEntityTag < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Element < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Attlist < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Notation < EntityTag
    end

    class Doctype < NamedEntity

	attr_reader :externalId, :entities

	def initialize(name, externalId, entities, source=nil)
	    super(name, source)
	    @externalId = externalId
	    @entities = entities
	end

	def ==(anObj)
	    return super(anObj) &&
		@externalId == anObj.externalId &&
		@entities == anObj.entities
	end
    end

end

==> ruby-nqxml-1.1.1.tgz: lib/ruby/site_ruby/1.6/nqxml/entities.rb <==
#
# Copyright (c) 2001 by Jim Menard <jimm@io.com>
#
# Released under the same license as Ruby. See
# http://www.ruby-lang.org/en/LICENSE.txt.
#

require 'nqxml/utils'

module NQXML

    class Entity

	attr_reader :source

	def initialize(source=nil)
	    @source = source
	end

	def to_s
	    return @source ? @source : ''
	end

	def ==(anObj)
	    return anObj.instance_of?(self.class) &&
		@source == anObj.source
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    io << self.to_s if beforeChildren
	end
    end

    # An abstract superclass for entities with names.
    class NamedEntity < Entity

	attr_reader :name

	def initialize(name, source=nil)
	    super(source)
	    @name = name
	end

	def ==(anObj)
	    return super(anObj) &&
		@name == anObj.name
	end
    end

    # An abstract superclass for entities with names and attributes.
    class NamedAttributes < NamedEntity
	attr_reader :attrs

	def initialize(name, attrs, source=nil)
	    super(name, source)
	    @attrs = attrs
	end

	def ==(anObj)
	    return super(anObj) &&
		@attrs == anObj.attrs
	end

	# Returns a string containing the attribute key/value pairs as XML.
	# Values are encoded.
	def attributesToXML
	    return '' if @attrs.nil?
	    str = ''
	    @attrs.each { | key, val |
		str << " #{key}=\"#{NQXML.encode(val.to_s)}\""
	    }
	    return str
	end

	# Returns a string containing the attribute key/value pairs as
	# a simple, unencoded string.
	def attributesToString
	    return '' if @attrs.nil?
	    str = ''
	    @attrs.each { | key, val |
		str << " #{key}=\"#{val.to_s}\""
	    }
	    return str
	end

    end

    class Tag < NamedAttributes

	attr_reader :isTagEnd

	def initialize(name, attrs, isTagEnd=false, source=nil)
	    super(name, attrs, source)
	    @isTagEnd = isTagEnd
	end

	def ==(anObj)
	    return super(anObj) &&
		@isTagEnd == anObj.isTagEnd
	end

	def isTagStart
	    return !@isTagEnd
	end
	alias_method :tagStart?, :isTagStart
	alias_method :tagEnd?, :isTagEnd

	# Write XML to io. Use the "<<" method, not print or puts, because
	# io might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    if beforeChildren
		io << "<#{name}" << attributesToXML() << ">"
	    else
		io << "</#{name}>"
	    end
	end

	# Prints tag. If it's start of tag, prints unencoded attributes.
	def to_s
	    return isTagEnd ? "</#{name}>" :
		"<#{name}" << attributesToString() << ">"
	end
    end

    class Text < Entity

	attr_reader :text

	def initialize(text, source=nil)
	    super(source)
	    @text = text
	end

	# We ignore the source attribute because during parsing entity
	# reference substitution may cause us to lose the ability to know
	# what the original XML source was.
	def ==(anObj)
	    return anObj.instance_of?(self.class) &&
  		@text == anObj.text
	end

	# Returns text with all entities replaced.
	def to_s
	    return @text
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# io might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    if beforeChildren
		io << @source if @source
		io << NQXML.encode(@text) if !@source
	    end
	end
    end

    class Comment < Entity

	attr_reader :text

	def initialize(source, internalEntities = nil)
	    super(source)

	    @source =~ /<!--(.*)-->/m
	    @text = $1.strip()
	end

	def ==(anObj)
	    return super(anObj) &&
		@text == anObj.text
	end
    end

    # Used for all processing instructions except '<?xml version="1.0"?>'.
    class ProcessingInstruction < NamedEntity

	attr_reader :text

	def initialize(name, text='', source=nil)
	    super(name, source)
	    @text = text
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    io << "<?#{name} #{text}?>" if beforeChildren
	end
    end

    # Only used for the '<?xml version="1.0"?>' processing instruction.
    class XMLDecl < NamedAttributes
	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    io << "<?xml" << attributesToXML() << "?>" if beforeChildren
	end
    end

    class EntityTag < NamedEntity

	attr_reader :text

	def initialize(name, text, source=nil)
	    super(name, source)
	    @text = text
	end

	def ==(anObj)
	    return super(anObj) &&
		@text == anObj.text
	end
    end

    class GeneralEntityTag < EntityTag
    end

    class ParameterEntityTag < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Element < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Attlist < EntityTag
    end

    # For now, behaves exactly like entity tag. Will change later.
    class Notation < EntityTag
    end

    class Doctype < NamedEntity

	attr_reader :externalId, :entities

	def initialize(name, externalId, entities, source=nil)
	    super(name, source)
	    @externalId = externalId
	    @entities = entities
	end

	def ==(anObj)
	    return super(anObj) &&
		@externalId == anObj.externalId &&
		@entities == anObj.entities
	end

	# Write XML to io. Use the "<<" method, not print or puts, because
	# this might be a String or Array and not an IO object.
	def writeXMLTo(io, beforeChildren=true)
	    if beforeChildren
		io << "<!DOCTYPE #{@name} #{@externalId}"
		if @entities && !@entities.empty?
		    io << ' ['
		    @entities.each { | e |
			io << "\n"
			e.writeXMLTo(io, beforeChildren)
		    }
		    io << ']>'
		else
		    io << '>'
		end
	    end
	end
    end

end
